//
// C++ Interface: komposesystray
//
// Description:
//
//
// Author: Hans Oischinger <hans.oischinger@kde-mail.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//
#ifndef KOMPOSESYSTRAY_H
#define KOMPOSESYSTRAY_H

#include <ksystemtray.h>

#include <tqimage.h>

class TDEAction;
class TDEGlobalAccel;
class TDEPopupMenu;

/**
@author Hans Oischinger
*/
class KomposeSysTray : public KSystemTray
{
  TQ_OBJECT
public:
  KomposeSysTray(TQWidget *parent = 0, const char *name = 0);
  ~KomposeSysTray();

  void currentDesktopChanged(int desktop);

protected:
  void mouseReleaseEvent (TQMouseEvent *);
  void mousePressEvent (TQMouseEvent *);

protected slots:
  void slotConfigChanged();

private:
  TDEPopupMenu *menu;
  TQImage icon;
};

#endif
